import os
import google.auth

from google.cloud import secretmanager


def _set_secret(sm_client: secretmanager.SecretManagerServiceClient, secret: str):
    name = secret.split("/")[-1]
    value = sm_client.access_secret_version(name=secret+"/versions/latest").payload.data.decode("utf-8")
    os.environ[name] = value


def set_secrets_as_envs():
    sm_client = secretmanager.SecretManagerServiceClient()
    _, project_id = google.auth.default()
    secrets = [secret.name for secret in list(sm_client.list_secrets(parent=f"projects/{project_id}"))]
    for secret in secrets:
        _set_secret(sm_client, secret)



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages


with open('requirements.txt') as f:
    install_requires = f.read().strip().split('\n')

setup(
    name='dataverk-gsm',
    version='0.0.2',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    python_requires='>=3.6',
    install_requires=install_requires,
    # metadata to display on PyPI
    author="NAV IKT",
    description="GSM integration for dataverk",
    license="MIT",
    keywords="gsm dataverk",
    url="https://github.com/navikt"
)
